********************************
The sherpa.utils.parallel module
********************************

.. currentmodule:: sherpa.utils.parallel

.. automodule:: sherpa.utils.parallel

   .. rubric:: Constants

   .. autosummary::
      :toctree: api

      context
      multi
      ncpus

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      parallel_map
      parallel_map_funcs
      parallel_map_rng
      run_tasks
